/*
 *
 *
 *    util.cc - misc functions used by the main program; placed here to
 *              make daylog.cc more manageable in size.
 *
 *    Copyright (C) 2002,2003 by Matt Roberts, KK5JY,
 *    All rights reserved.
 *
 *    ---------------- L I C E N S E    S T A T E M E N T -------------------
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 *    ----------------------- E N D    L I C E N S E ------------------------
 *
 *
 */


#include <string>

#include <sys/time.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <signal.h>
#include <stdlib.h>
#include <errno.h>
#include <fcntl.h>
#include <ctype.h>
#include <time.h>

#include "util.h"


/*
 *
 *   write_line(int, string)
 *
 */

bool write_line (int fd, std::string &s, const std::string &el) {
	// if s is empty, do nothing
	if (s.empty())
		return true;

	// find the first newline
	std::string::size_type idx = s.find('\n');

	// number of bytes to write
	size_t len = 0;

	// if no complete lines are available, make one out of what we have
	if (idx == std::string::npos) {
		s += el;
		len = s.size();
	} else {
		len = idx + 1;
	}

	// write to device
	ssize_t count = ::write(fd, s.c_str(), len);

	// if no bytes could be written, return success anyway
	if (count == 0)
		return true;

	// if an error occurred that was not EAGAIN, return error
	if (count < 0)
		return (errno == EAGAIN);

	// otherwise, adjust the buffer, according to the number of bytes sent
	if ((size_t)count <= s.size())
		s.erase(0, count);
	else
		s.erase();

	// return
	return true;
}


/*
 *
 *   times_differ(time1, time2)
 *
 */

bool times_differ (struct tm &time1, struct tm &time2) {
	// if 'minute' or anything more significant has changed, then
	//    return 'true': this is a VERY paranoid check
	return (
			(time1.tm_min  != time2.tm_min)  ||
			(time1.tm_hour != time2.tm_hour) ||
			(time1.tm_mday != time2.tm_mday) ||
			(time1.tm_mon  != time2.tm_mon)  ||
			(time1.tm_year != time2.tm_year)
		   );
}


/*
 *
 *   fexist(fn)
 *
 */

bool fexist (const std::string &s) {
	struct stat buf;
	int rtn = stat(s.c_str(), &buf);
	if (rtn < 0)
		return false;
	return (S_ISREG(buf.st_mode));
}


// end-of-file: util.cc
